        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 36 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,10,11,12,13,14,15,17,18,19,20,23,24,25,26,28,29,31,32,35,36,38,39,40,43,45,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 15 <br>9,16,21,22,27,30,33,34,37,41,42,44,46,47,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 36 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,10,11,12,13,14,15,17,18,19,20,23,24,25,26,28,29,31,32,35,36,38,39,40,43,45,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 15 <br>9,16,21,22,27,30,33,34,37,41,42,44,46,47,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 36 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,10,11,12,13,14,15,17,18,19,20,23,24,25,26,28,29,31,32,35,36,38,39,40,43,45,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 15 <br>9,16,21,22,27,30,33,34,37,41,42,44,46,47,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 36 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,10,11,12,13,14,15,17,18,19,20,23,24,25,26,28,29,31,32,35,36,38,39,40,43,45,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 15 <br>9,16,21,22,27,30,33,34,37,41,42,44,46,47,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 36 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,10,11,12,13,14,15,17,18,19,20,23,24,25,26,28,29,31,32,35,36,38,39,40,43,45,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260426 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>46</strong> miembros: 15 <br>9,16,21,22,27,30,33,34,37,41,42,44,46,47,48';}
}
